@@ -20,17 +20,17 @@
 #ifndef FRAMEVIEW_H
 #define FRAMEVIEW_H
 
-#include "src/presentation/imagecache.h"
-#include "src/domain/animation/workspacefile.h"
-
-#include <QWidget>
+#include <QObject>
 #include <QTimer>
+#include <QWidget>
+
+#include "src/domain/animation/workspacefile.h"
+#include "src/presentation/imagecache.h"
 
 class ImageGrabThread;
 class QResizeEvent;
 class QPaintEvent;
 class QPixmap;
-class ImageGrabThread;
 class ImageGrabber;
 class DomainFacade;
 
@@ -51,7 +51,7 @@ public:
 	* @param parent the parent widget.
 	* @param name the name of this widget.
 	* @param playbackSpeed which speed the playback has to be played in if
-	* the playback mode is choosen
+	* the playback mode is chosen
 	*/
 	FrameView(QWidget *parent=0, const char *name=0, int playbackSpeed = 10);
 
@@ -68,7 +68,7 @@ public:
 	 *             0: Image mixing/onion skinning\n
 	 *             1: Image differentiating\n
 	 *             2: Playback\n
-	 * @return true if the mode was succesfully changed
+	 * @return true if the mode was successfully changed
 	 */
 	bool setViewMode(ImageMode mode);
 
